###########
pyRSKtools
###########

pyRSKtools is RBR's open source Python toolbox for reading, post-processing, visualizing, and exporting RBR logger data. 
Users may plot data as a time series or as depth profiles using tailored plotting utilities. Time-depth heat maps can be
plotted easily to visualize transects or moored profiler data. A full suite of data post-processing functionality, such as
methods to match sensor time constants and bin average, are available to enhance data quality.

For more information, please see our pyRSKtools `documentation <https://docs.rbr-global.com/pyrsktools/>`_.
